/* jshint globalstrict:true */
'use strict';

const TEXT_OVERLAY_CONTAINER_NAME = 'locrmaps-text-overlay';

document.addEventListener('DOMContentLoaded', function() {
    const textOverlays = document.getElementsByName( TEXT_OVERLAY_CONTAINER_NAME );
    for (const textOverlay of textOverlays) {
        textOverlay.addEventListener('keyup', onKeyUp);
    }
});

/**
 * @param {Event} event
 */
function onKeyUp( event ) {
    const target = event.target;
    if ( ! ( target instanceof HTMLInputElement ) && ! ( target instanceof HTMLTextAreaElement ) ) {
        return;
    }

    let id = target.id;
    const idMatch = id.match(/locrmaps-text-overlay-(?<id>.+)/);
    if ( idMatch?.groups?.id && idMatch.groups.id.trim() !== '' ) {
        id = idMatch.groups.id.trim();
    }
    const dataOverlayRefIdAttr = target.attributes.getNamedItem('data-overlay-ref-id');
    if (dataOverlayRefIdAttr instanceof window.Attr && dataOverlayRefIdAttr.value.trim() !== '') {
        id = dataOverlayRefIdAttr.value.trim();
    }

    const eventDetails = {
        id,
        content: target.value,
        attributes: {},
    };

    const dataXAttr = target.attributes.getNamedItem('data-x');
    if (dataXAttr instanceof window.Attr && dataXAttr.value.trim() !== '') {
        eventDetails.attributes.x = dataXAttr.value.trim();
    }
    const dataYAttr = target.attributes.getNamedItem('data-y');
    if (dataYAttr instanceof window.Attr && dataYAttr.value.trim() !== '') {
        eventDetails.attributes.y = dataYAttr.value.trim();
    }

    document.dispatchEvent(new CustomEvent('locr.locrmaps.set-text-overlay', { detail: eventDetails }));
}
